@@ -1,7 +1,7 @@
 package Perinci::Sub::To::FuncBase;
 
-our $DATE = '2015-09-29'; # DATE
-our $VERSION = '0.68'; # VERSION
+our $DATE = '2015-12-17'; # DATE
+our $VERSION = '0.69'; # VERSION
 
 use 5.010;
 use Log::Any::IfLOG '$log';
@@ -189,12 +189,13 @@ sub gen_doc_section_result {
     my $riresmeta = rimeta($meta->{result});
     my $dres      = $self->{_doc_res};
 
+    my $orig_result_naked = $meta->{_orig_result_naked};
+
     $dres->{res_schema} = $meta->{result} ? $meta->{result}{schema} : undef;
     $dres->{res_schema} //= [any => {}];
     $dres->{human_res} = terse_schema($dres->{res_schema});
 
-    my $rn = $meta->{result_naked};
-    if ($rn) {
+    if ($orig_result_naked) {
         $dres->{human_ret} = $dres->{human_res};
     } else {
         $dres->{human_ret} = '[status, msg, result, meta]';
@@ -223,7 +224,7 @@ Perinci::Sub::To::FuncBase - Base class for Perinci::Sub::To::* function documen
 
 =head1 VERSION
 
-This document describes version 0.68 of Perinci::Sub::To::FuncBase (from Perl distribution Perinci-To-Doc), released on 2015-09-29.
+This document describes version 0.69 of Perinci::Sub::To::FuncBase (from Perl distribution Perinci-To-Doc), released on 2015-12-17.
 
 =for Pod::Coverage .+
 
