@@ -1,7 +1,7 @@
 package Perinci::Sub::To::Text;
 
-our $DATE = '2015-09-29'; # DATE
-our $VERSION = '0.68'; # VERSION
+our $DATE = '2015-12-17'; # DATE
+our $VERSION = '0.69'; # VERSION
 
 use 5.010001;
 use Log::Any::IfLOG '$log';
@@ -24,6 +24,8 @@ sub after_gen_doc {
     my $meta  = $self->meta;
     my $dres  = $self->{_doc_res};
 
+    my $orig_result_naked = $meta->{_orig_result_naked};
+
     $self->add_doc_lines(
         "+ ".$dres->{name}.$dres->{args_plterm}.' -> '.$dres->{human_ret},
     );
@@ -72,7 +74,6 @@ sub after_gen_doc {
 
     $self->add_doc_lines("", __("Return value") . ':');
     $self->inc_doc_indent;
-    my $rn = $meta->{result_naked};
     $self->add_doc_lines(__(
 "Returns an enveloped result (an array).
 
@@ -82,7 +83,7 @@ First element (status) is an integer containing HTTP status code
 200. Third element (result) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information."))
-        unless $rn;
+        unless $orig_result_naked;
     $self->add_doc_lines($dres->{res_summary} . ($dres->{res_schema} ? " ($dres->{res_schema}[0])" : "")) if $dres->{res_summary};
 
     $self->dec_doc_indent;
@@ -105,7 +106,7 @@ Perinci::Sub::To::Text - Generate text documentation from Rinci function metadat
 
 =head1 VERSION
 
-This document describes version 0.68 of Perinci::Sub::To::Text (from Perl distribution Perinci-To-Doc), released on 2015-09-29.
+This document describes version 0.69 of Perinci::Sub::To::Text (from Perl distribution Perinci-To-Doc), released on 2015-12-17.
 
 =head1 SYNOPSIS
 
