@@ -1,7 +1,7 @@
 package Perinci::To::PackageBase;
 
-our $DATE = '2015-09-29'; # DATE
-our $VERSION = '0.68'; # VERSION
+our $DATE = '2015-12-17'; # DATE
+our $VERSION = '0.69'; # VERSION
 
 use 5.010;
 use Data::Dump::OneLine qw(dump1);
@@ -111,7 +111,7 @@ sub gen_doc_section_functions {
                 parent=>$self,
                 name=>$fname,
                 meta=>$meta,
-                url=>"$self->{url}$furi",
+                url=> ($self->{url}//'') . $furi,
             );
     }
 }
@@ -134,7 +134,7 @@ Perinci::To::PackageBase - Base class for Perinci::To::* package documentation g
 
 =head1 VERSION
 
-This document describes version 0.68 of Perinci::To::PackageBase (from Perl distribution Perinci-To-Doc), released on 2015-09-29.
+This document describes version 0.69 of Perinci::To::PackageBase (from Perl distribution Perinci-To-Doc), released on 2015-12-17.
 
 =for Pod::Coverage .+
 
